AutoLayoutHelper class

A helper for AutoLayout to make it easier develop for different screen sizes.

Constructors

AutoLayoutHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isLarge(double width) → bool
returns true if the width is greater than MEDIUM
isMedium(double width) → bool
returns true if the width is in the MEDIUM range
isNarrow(double width) → bool
returns true if the width is in the NARROW range
isSmall(double width) → bool
returns true if the width is in the SMALL range

Constants

DEFAULT_SCREEN_SIZES → const List<double>
default screen sizes as a list so that you can use it as the AutoLayout.breakpoints
LARGE → const double
values after 950 are considered LARGE
MEDIUM → const double
values between (650 - 950) are considered MEDIUM
NARROW → const double
values less than 300 are considered NARROW
SMALL → const double
values between (300 - 650) are considered SMALL