IAutoLayout class abstract

An interface to make it easier to implement auto layout capabilities

Available extensions

Constructors

IAutoLayout()

Properties

hashCode → int
The hash code for this object.
no setterinherited
layout → AutoLayout

Available on IAutoLayout, provided by the AutoLayoutExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildLarge(BuildContext context, BoxConstraints constraints) → Widget
buildMedium(BuildContext context, BoxConstraints constraints) → Widget
buildSmall(BuildContext context, BoxConstraints constraints) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited